@@ -3,20 +3,53 @@ Various small and named graphs, together with some compact generators.
 
 """
 __author__ ="""Aric Hagberg (hagberg@lanl.gov)\nPieter Swart (swart@lanl.gov)"""
-__date__ = "$Date: 2005-06-15 12:53:08 -0600 (Wed, 15 Jun 2005) $"
-__credits__ = """"""
-__revision__ = "$Revision: 1040 $"
-#    Copyright (C) 2004,2005 by 
+#    Copyright (C) 2004-2008 by 
 #    Aric Hagberg <hagberg@lanl.gov>
 #    Dan Schult <dschult@colgate.edu>
 #    Pieter Swart <swart@lanl.gov>
-#    Distributed under the terms of the GNU Lesser General Public License
-#    http://www.gnu.org/copyleft/lesser.html
-import networkx
+#    All rights reserved.
+#    BSD license.
+
+__all__ = ['make_small_graph',
+           'LCF_graph',
+           'bull_graph',
+           'chvatal_graph',
+           'cubical_graph',
+           'desargues_graph',
+           'diamond_graph',
+           'dodecahedral_graph',
+           'frucht_graph',
+           'heawood_graph',
+           'house_graph',
+           'house_x_graph',
+           'icosahedral_graph',
+           'krackhardt_kite_graph',
+           'moebius_kantor_graph',
+           'octahedral_graph',
+           'pappus_graph',
+           'petersen_graph',
+           'sedgewick_maze_graph',
+           'tetrahedral_graph',
+           'truncated_cube_graph',
+           'truncated_tetrahedron_graph',
+           'tutte_graph']
+
+from networkx.generators.classic import empty_graph, cycle_graph, path_graph, complete_graph
+from networkx.exception import NetworkXError
 
 #------------------------------------------------------------------------------
 #   Tools for creating small graphs
 #------------------------------------------------------------------------------
+def make_small_undirected_graph(graph_description, create_using=None):
+    """
+    Return a small undirected graph described by graph_description.
+
+    See make_small_graph.
+    """
+    if create_using is not None and create_using.is_directed():
+        raise NetworkXError("Directed Graph not supported")
+    return make_small_graph(graph_description, create_using)
+
 def make_small_graph(graph_description, create_using=None):
     """
     Return the small graph described by graph_description.
@@ -25,25 +58,25 @@ def make_small_graph(graph_description, create_using=None):
 
     Here ltype is one of "adjacencylist" or "edgelist",
     name is the name of the graph and n the number of nodes.
-    This constructs a graph of  n nodes with integer labels 1,..,n.
+    This constructs a graph of n nodes with integer labels 0,..,n-1.
     
     If ltype="adjacencylist"  then xlist is an adjacency list
     with exactly n entries, in with the j'th entry (which can be empty)
     specifies the nodes connected to vertex j.
     e.g. the "square" graph C_4 can be obtained by
 
-    >>> G=make_small_graph(["adjacencylist","C_4",4,[[2,4],[1,3],[2,4],[1,3]]])
+    >>> G=nx.make_small_graph(["adjacencylist","C_4",4,[[2,4],[1,3],[2,4],[1,3]]])
 
     or, since we do not need to add edges twice,
     
-    >>> G=make_small_graph(["adjacencylist","C_4",4,[[2,4],[3],[4],[]]])
+    >>> G=nx.make_small_graph(["adjacencylist","C_4",4,[[2,4],[3],[4],[]]])
     
     If ltype="edgelist" then xlist is an edge list 
     written as [[v1,w2],[v2,w2],...,[vk,wk]],
     where vj and wj integers in the range 1,..,n
     e.g. the "square" graph C_4 can be obtained by
  
-    >>> G=make_small_graph(["edgelist","C_4",4,[[1,2],[3,4],[2,3],[4,1]]])
+    >>> G=nx.make_small_graph(["edgelist","C_4",4,[[1,2],[3,4],[2,3],[4,1]]])
 
     Use the create_using argument to choose the graph class/type. 
     """
@@ -51,13 +84,13 @@ def make_small_graph(graph_description, create_using=None):
     name=graph_description[1]
     n=graph_description[2]
 
-    G=networkx.empty_graph(n, create_using)
+    G=empty_graph(n, create_using)
     nodes=G.nodes()
 
     if ltype=="adjacencylist":
         adjlist=graph_description[3]
         if len(adjlist) != n:
-            raise networkx.NetworkXError,"invalid graph_description"
+            raise NetworkXError,"invalid graph_description"
         G.add_edges_from([(u-1,v) for v in nodes for u in adjlist[v]])
     elif ltype=="edgelist":
         edgelist=graph_description[3]
@@ -65,14 +98,14 @@ def make_small_graph(graph_description, create_using=None):
             v1=e[0]-1
             v2=e[1]-1
             if v1<0 or v1>n-1 or v2<0 or v2>n-1:
-                raise networkx.NetworkXError,"invalid graph_description"
+                raise NetworkXError,"invalid graph_description"
             else:
                 G.add_edge(v1,v2)
     G.name=name
     return G
 
 
-def LCF_graph(n,shift_list,repeats):
+def LCF_graph(n,shift_list,repeats,create_using=None):
     """
     Return the cubic graph specified in LCF notation.
 
@@ -98,22 +131,24 @@ def LCF_graph(n,shift_list,repeats):
           
     The utility graph K_{3,3}
 
-    >>> G=LCF_graph(6,[3,-3],3)
+    >>> G=nx.LCF_graph(6,[3,-3],3)
     
     The Heawood graph
 
-    >>> G=LCF_graph(14,[5,-5],7)
+    >>> G=nx.LCF_graph(14,[5,-5],7)
 
     See http://mathworld.wolfram.com/LCFNotation.html for a description
     and references.
     
     """
+    if create_using is not None and create_using.is_directed():
+        raise NetworkXError("Directed Graph not supported")
 
     if n <= 0:
-        return networkx.empty_graph()
+        return empty_graph(0, create_using)
 
     # start with the n-cycle
-    G=networkx.cycle_graph(n)
+    G=cycle_graph(n, create_using)
     G.name="LCF_graph"
     nodes=G.nodes()
 
@@ -135,7 +170,7 @@ def LCF_graph(n,shift_list,repeats):
 #   Various small and named graphs
 #-------------------------------------------------------------------------------
 
-def bull_graph():
+def bull_graph(create_using=None):
     """Return the Bull graph. """
     description=[
         "adjacencylist",
@@ -143,10 +178,10 @@ def bull_graph():
         5,
         [[2,3],[1,3,4],[1,2,5],[2],[3]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
-def chvatal_graph():
+def chvatal_graph(create_using=None):
     """Return the Chvatal graph."""
     description=[
         "adjacencylist",
@@ -156,10 +191,10 @@ def chvatal_graph():
          [6,9],[11,12],[11,12],[9,12],
          [11],[11,12],[],[]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
-def cubical_graph():
+def cubical_graph(create_using=None):
     """Return the 3-regular Platonic Cubical graph."""
     description=[
         "adjacencylist",
@@ -168,16 +203,16 @@ def cubical_graph():
         [[2,4,5],[1,3,8],[2,4,7],[1,3,6],
          [1,6,8],[4,5,7],[3,6,8],[2,5,7]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
-def desargues_graph():
+def desargues_graph(create_using=None):
     """ Return the Desargues graph."""
-    G=LCF_graph(20,[5,-5,9,-9],5)
+    G=LCF_graph(20, [5,-5,9,-9], 5, create_using)
     G.name="Desargues Graph"
     return G
 
-def diamond_graph():
+def diamond_graph(create_using=None):
     """Return the Diamond graph. """
     description=[
         "adjacencylist",
@@ -185,36 +220,36 @@ def diamond_graph():
         4,
         [[2,3],[1,3,4],[1,2,4],[2,3]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
-def dodecahedral_graph():
+def dodecahedral_graph(create_using=None):
     """ Return the Platonic Dodecahedral graph. """
-    G=LCF_graph(20,[10,7,4,-4,-7,10,-4,7,-7,4],2)
+    G=LCF_graph(20, [10,7,4,-4,-7,10,-4,7,-7,4], 2, create_using)
     G.name="Dodecahedral Graph"
     return G
 
-def frucht_graph():
+def frucht_graph(create_using=None):
     """Return the Frucht Graph.
 
     The Frucht Graph is the smallest cubical graph whose
     automorphism group consists only of the identity element.
 
     """
-    G=networkx.cycle_graph(7)
+    G=cycle_graph(7, create_using)
     G.add_edges_from([[0,7],[1,7],[2,8],[3,9],[4,9],[5,10],[6,10],
                 [7,11],[8,11],[8,9],[10,11]])
 
     G.name="Frucht Graph"
     return G
 
-def heawood_graph():
+def heawood_graph(create_using=None):
     """ Return the Heawood graph, a (3,6) cage. """
-    G=LCF_graph(14,[5,-5],7)
+    G=LCF_graph(14, [5,-5], 7, create_using)
     G.name="Heawood Graph"
     return G
 
-def house_graph():
+def house_graph(create_using=None):
     """Return the House graph (square with triangle on top)."""
     description=[
         "adjacencylist",
@@ -222,10 +257,10 @@ def house_graph():
         5,
         [[2,3],[1,4],[1,4,5],[2,3,5],[3,4]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
-def house_x_graph():
+def house_x_graph(create_using=None):
     """Return the House graph with a cross inside the house square."""
     description=[
         "adjacencylist",
@@ -233,10 +268,10 @@ def house_x_graph():
         5,
         [[2,3,4],[1,3,4],[1,2,4,5],[1,2,3,5],[3,4]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
-def icosahedral_graph():
+def icosahedral_graph(create_using=None):
     """Return the Platonic Icosahedral graph."""
     description=[
         "adjacencylist",
@@ -246,11 +281,11 @@ def icosahedral_graph():
          [6,7,11,12],[7,12],[],[9,10,11,12],
          [10],[11],[12],[]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
     
 
-def krackhardt_kite_graph():
+def krackhardt_kite_graph(create_using=None):
     """
     Return the Krackhardt Kite Social Network.
  
@@ -268,16 +303,16 @@ def krackhardt_kite_graph():
         [[2,3,4,6],[1,4,5,7],[1,4,6],[1,2,3,5,6,7],[2,4,7],
          [1,3,4,7,8],[2,4,5,6,8],[6,7,9],[8,10],[9]]
          ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
-def moebius_kantor_graph():
+def moebius_kantor_graph(create_using=None):
     """Return the Moebius-Kantor graph."""
-    G=LCF_graph(16,[5,-5],8)
+    G=LCF_graph(16, [5,-5], 8, create_using)
     G.name="Moebius-Kantor Graph"
     return G    
 
-def octahedral_graph():
+def octahedral_graph(create_using=None):
     """Return the Platonic Octahedral graph."""
     description=[
         "adjacencylist",
@@ -285,7 +320,7 @@ def octahedral_graph():
         6,
         [[2,3,4,5],[3,4,6],[5,6],[5,6],[6],[]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
     
 def pappus_graph():
@@ -294,7 +329,7 @@ def pappus_graph():
     G.name="Pappus Graph"
     return G
 
-def petersen_graph():
+def petersen_graph(create_using=None):
     """Return the Petersen graph."""
     description=[
         "adjacencylist",
@@ -303,11 +338,11 @@ def petersen_graph():
         [[2,5,6],[1,3,7],[2,4,8],[3,5,9],[4,1,10],[1,8,9],[2,9,10],
          [3,6,10],[4,6,7],[5,7,8]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
 
-def sedgewick_maze_graph():
+def sedgewick_maze_graph(create_using=None):
     """
     Return a small maze with a cycle.
 
@@ -315,7 +350,7 @@ def sedgewick_maze_graph():
     Algorithms, Chapter 18, e.g. Figure 18.2 and following.
     Nodes are numbered 0,..,7
     """ 
-    G=networkx.empty_graph(0)
+    G=empty_graph(0, create_using)
     G.add_nodes_from(range(8))
     G.add_edges_from([[0,2],[0,7],[0,5]])
     G.add_edges_from([[1,7],[2,6]])
@@ -324,14 +359,13 @@ def sedgewick_maze_graph():
     G.name="Sedgewick Maze"
     return G
 
-def tetrahedral_graph():
+def tetrahedral_graph(create_using=None):
     """ Return the 3-regular Platonic Tetrahedral graph."""
-    from networkx.generators.classic import complete_graph
-    G=complete_graph(4)
+    G=complete_graph(4, create_using)
     G.name="Platonic Tetrahedral graph"
     return G
 
-def truncated_cube_graph():
+def truncated_cube_graph(create_using=None):
     """Return the skeleton of the truncated cube."""
     description=[
         "adjacencylist",
@@ -344,18 +378,18 @@ def truncated_cube_graph():
          [18,19],[21],[20],[24],
          [22],[23],[24],[]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
-def truncated_tetrahedron_graph():
+def truncated_tetrahedron_graph(create_using=None):
     """Return the skeleton of the truncated Platonic tetrahedron."""
-    G=networkx.path_graph(12)
+    G=path_graph(12, create_using)
 #    G.add_edges_from([(1,3),(1,10),(2,7),(4,12),(5,12),(6,8),(9,11)])
     G.add_edges_from([(0,2),(0,9),(1,6),(3,11),(4,11),(5,7),(8,10)])
     G.name="Truncated Tetrahedron Graph"
     return G
 
-def tutte_graph():
+def tutte_graph(create_using=None):
     """Return the Tutte graph."""
     description=[
         "adjacencylist",
@@ -371,29 +405,6 @@ def tutte_graph():
          [37],[38,40],[39],[],[],
          [42,45],[43],[44,46],[45],[],[]]
         ]
-    G=make_small_graph(description)
+    G=make_small_undirected_graph(description, create_using)
     return G
 
-
-def _test_suite():
-    """test hook"""
-    import doctest
-    suite = doctest.DocFileSuite('tests/generators/small.txt',\
-                                 package='networkx')
-    return suite
-
-if __name__ == "__main__":
-    import os
-    import sys
-    import unittest
-    if sys.version_info[:2] < (2, 4):
-        print "Python version 2.4 or later required for tests (%d.%d detected)"\
-              %  sys.version_info[:2]
-        sys.exit(-1)
-    # directory of networkx package (relative to this)
-    nxbase=sys.path[0]+os.sep+os.pardir
-    sys.path.insert(0,nxbase) # prepend to search path
-    unittest.TextTestRunner().run(_test_suite())
-    
-
-
